# grocery_list =["milk", "bread", "eggs", "cheese", "apples"]
# print(grocery_list)
# grocery_list.append("chocolate")
# print(grocery_list)
# del(grocery_list[1])
# print(grocery_list)
# print(len(grocery_list))
# grocery_list.sort()
# print(grocery_list)
# print(grocery_list[0])
# print(grocery_list[4])
# print(grocery_list[-1])  # last item
list_numbers =[10,2,45,1,2,4,5,7,9,2,4,790]
list_numbers.sort()
list_numbers.reverse()
print(list_numbers)